<?php
namespace FM\Service;

use FM\Factory\SolicitacaoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use FM\Service\FileServerService;

class SolicitacaoService {
    
    protected $SolicitacaoFactory;
    protected $environment;
    protected $newCode;
    protected $connection;
    protected $FileServerService;
    protected $fileServerApiKeys;
    
    public function __construct (SolicitacaoFactory $SolicitacaoFactory, Environment $Environment, NewCode $newCode, EntityManager $entityManager, FileServerService $FileServerService, $fileServerApiKeys) {
        $this->SolicitacaoFactory           = $SolicitacaoFactory;
        $this->environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection(); 
        $this->FileServerService = $FileServerService;
        $this->fileServerApiKeys = $fileServerApiKeys;
    }
       
    public function getLocalRequest($params) {
        return $this->SolicitacaoFactory->getLocalRequest($params);
    }


    public function setNewRequest($parametros) {
        $this->connection->beginTransaction();

         try {
                $NRORG = $this->environment->getNrOrg();
                $NRSOLICITACAO = $this->newCode->getCodeByTableName("FCM_SOLICITACAO", $NRORG, 1, 10, true);
                $params = array(
                    "NRSOLICITACAO"  => $NRSOLICITACAO,
                    "NMSOLICITACAO"  => $parametros['NMSOLICITACAO'],
                    "IDSITUACAO"     => $parametros['IDSITUACAO'],
                    "NRLOCALCLIENTE" => $parametros['NRLOCALCLIENTE'],
                    "CDOPERABERTURA" => $this->environment->getCdOperador(),
                    "DSSOLICITACAO"  => $parametros['DSSOLICITACAO'],
                    "NRORG"          => $NRORG
                );
                $this->SolicitacaoFactory->insertNewRequest($params);

                $NRSOLICITACAOHISTORICO = $this->newCode->getCodeByTableName("FCM_SOLICITACAOHISTORICO", $NRORG, 1, 10, true);

                $params = array(
                    "NRSOLICITACAOHISTORICO" => $NRSOLICITACAOHISTORICO,
                    "NRSOLICITACAO"          => $NRSOLICITACAO,
                    "IDSITUACAO"             => 1,
                    "IDTIPOHISTORICO"        => 1,
                    "CDOPERSOLICITANTE"      => $this->environment->getCdOperador(),
                    "DSSOLICITACAO"          => $parametros['DSSOLICITACAO'],
                    "IDSATISFACAOSOLICITA"   => null,
                    "NRORG"                  => $NRORG
                );

                $this->SolicitacaoFactory->insertRequestHistory($params);

                $row = $this->FileServerService->uploadImagensManut($parametros['IMAGENS']);
                foreach ($row as $file) {
                    $this->SolicitacaoFactory->insertImg(array(
                        "NRIMGSOLICITACAO" => $this->newCode->getCodeByTableName('FCM_IMGSOLICITACAO', $this->environment->getNrOrg(), 1, 10, true),
                        "NRSOLICITACAO" => $NRSOLICITACAO,
                        "DSCAMINHO" => $file['DS'],
                        "NRORG" => $NRORG,
                        "DSTYPE" => $file['DSTYPE'],
                        "NRSIZE" => $file['QTSIZE'],
                        "CDOPERINCLUSAO" => $this->environment->getCdOperador()
                    ));
                }

            $this->connection->commit();

        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getCardsRequests($parametro, $parametroIds) {

        $param = '';

        if ($parametro['selectName'] != '' && $parametro['selectName'] != null) {
            $param = $param." AND S.NRSOLICITACAO = ".$parametro['selectName'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
            $param = $param." AND S.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        if ($parametro['selectSituation'] != '' && $parametro['selectSituation'] != null) {
            $param = $param." AND S.IDSITUACAO = ".$parametro['selectSituation'];
        }

        if ($parametro['TO_CHAR(S.DTSOLICITACAO,\'DD/MM/YYYY\')'] != '' && $parametro['TO_CHAR(S.DTSOLICITACAO,\'DD/MM/YYYY\')'] != null && strlen($parametro['TO_CHAR(S.DTSOLICITACAO,\'DD/MM/YYYY\')']) == 21) {
            $param = $param." AND TO_CHAR(S.DTSOLICITACAO,'DD/MM/YYYY') = ".$parametro['TO_CHAR(S.DTSOLICITACAO,\'DD/MM/YYYY\')'];
        }

        $usersIds = implode(',',$parametroIds); // Transforma o array em uma string com os ids

        return $this->SolicitacaoFactory->getCardsRequests($param, $usersIds);
    }

    public function showRequest($params) {

        $parametros = array(
            "NRSOLICITACAO"    => $params['NRSOLICITACAO'],
        );

        return $this->SolicitacaoFactory->showRequest($parametros);
    }

    public function getSituationRequest() {

        return $this->SolicitacaoFactory->getSituationRequest();
    }

    public function getNameRequest() {

        return $this->SolicitacaoFactory->getNameRequest();
    }

    public function evaluateRequest($parametros) {
        $this->connection->beginTransaction();

         try {
            $NRORG = $this->environment->getNrOrg();
            $params = array(
                "NRSOLICITACAO"        => $parametros['NRSOLICITACAO'],
                "IDSITUACAO"           => ($parametros['CONDITION']) ? 4 : 1,
                "DSSOLICITACAO"        => $parametros['DSSOLICITACAO']
            );
            $this->SolicitacaoFactory->upRequest($params);
            
            $NRSOLICITACAOHISTORICO = $this->newCode->getCodeByTableName("FCM_SOLICITACAOHISTORICO", $NRORG, 1, 10, true);

            $params = array(
                    "NRSOLICITACAOHISTORICO" => $NRSOLICITACAOHISTORICO,
                    "NRSOLICITACAO"          => $parametros['NRSOLICITACAO'],
                    "IDSITUACAO"             => ($parametros['CONDITION']) ? 4 : 1,
                    "IDTIPOHISTORICO"        => 4,
                    "CDOPERSOLICITANTE"      => $this->environment->getCdOperador(),
                    "DSSOLICITACAO"          => $parametros['DSSOLICITACAO'],
                    "IDSATISFACAOSOLICITA"   => $parametros['IDSATISFACAOSOLICITA'],
                    "NRORG"                  => $NRORG
                );
            $this->SolicitacaoFactory->insertRequestHistory($params);

            $this->connection->commit();

        }  catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
?>